@@ -29,7 +29,9 @@ from urllib.parse import ParseResult
 
 import yaml
 
+import datamodel_code_generator.pydantic_patch  # noqa: F401
 from datamodel_code_generator.format import PythonVersion
+from datamodel_code_generator.model.pydantic_v2 import UnionMode
 from datamodel_code_generator.parser import DefaultPutDict, LiteralType
 from datamodel_code_generator.parser.base import Parser
 from datamodel_code_generator.types import StrictTypes
@@ -58,22 +60,16 @@ def load_yaml_from_path(path: Path, encoding: str) -> Any:
 
 if TYPE_CHECKING:
 
-    def get_version() -> str:
-        ...
+    def get_version() -> str: ...
 
 else:
 
     def get_version() -> str:
         package = 'datamodel-code-generator'
 
-        try:
-            from importlib.metadata import version
+        from importlib.metadata import version
 
-            return version(package)
-        except ImportError:
-            import pkg_resources
-
-            return pkg_resources.get_distribution(package).version
+        return version(package)
 
 
 def enable_debug_message() -> None:  # pragma: no cover
@@ -241,7 +237,7 @@ def generate(
     input_file_type: InputFileType = InputFileType.Auto,
     output: Optional[Path] = None,
     output_model_type: DataModelType = DataModelType.PydanticBaseModel,
-    target_python_version: PythonVersion = PythonVersion.PY_37,
+    target_python_version: PythonVersion = PythonVersion.PY_38,
     base_class: str = '',
     additional_imports: Optional[List[str]] = None,
     custom_template_dir: Optional[Path] = None,
@@ -300,6 +296,11 @@ def generate(
     custom_file_header_path: Optional[Path] = None,
     custom_formatters: Optional[List[str]] = None,
     custom_formatters_kwargs: Optional[Dict[str, Any]] = None,
+    use_pendulum: bool = False,
+    http_query_parameters: Optional[Sequence[Tuple[str, str]]] = None,
+    treat_dots_as_module: bool = False,
+    use_exact_imports: bool = False,
+    union_mode: Optional[UnionMode] = None,
 ) -> None:
     remote_text_cache: DefaultPutDict[str, str] = DefaultPutDict()
     if isinstance(input_, str):
@@ -309,7 +310,9 @@ def generate(
 
         input_text = remote_text_cache.get_or_put(
             input_.geturl(),
-            default_factory=lambda url: get_body(url, http_headers, http_ignore_tls),
+            default_factory=lambda url: get_body(
+                url, http_headers, http_ignore_tls, http_query_parameters
+            ),
         )
     else:
         input_text = None
@@ -385,6 +388,13 @@ def generate(
     if isinstance(input_, ParseResult) and input_file_type not in RAW_DATA_TYPES:
         input_text = None
 
+    if union_mode is not None:
+        if output_model_type == DataModelType.PydanticV2BaseModel:
+            default_field_extras = {'union_mode': union_mode}
+        else:  # pragma: no cover
+            raise Error('union_mode is only supported for pydantic_v2.BaseModel')
+    else:
+        default_field_extras = None
     from datamodel_code_generator.model import get_data_model_types
 
     data_model_types = get_data_model_types(output_model_type, target_python_version)
@@ -456,6 +466,11 @@ def generate(
         known_third_party=data_model_types.known_third_party,
         custom_formatters=custom_formatters,
         custom_formatters_kwargs=custom_formatters_kwargs,
+        use_pendulum=use_pendulum,
+        http_query_parameters=http_query_parameters,
+        treat_dots_as_module=treat_dots_as_module,
+        use_exact_imports=use_exact_imports,
+        default_field_extras=default_field_extras,
         **kwargs,
     )
 
@@ -525,7 +540,7 @@ def infer_input_type(text: str) -> InputFileType:
 
 
 inferred_message = (
-    'The input file type was determined to be: {}\nThis can be specificied explicitly with the '
+    'The input file type was determined to be: {}\nThis can be specified explicitly with the '
     '`--input-file-type` option.'
 )
 
