@@ -1,6 +1,7 @@
+import re
+from enum import Enum
 from pathlib import Path
 from typing import (
-    TYPE_CHECKING,
     Any,
     ClassVar,
     DefaultDict,
@@ -12,6 +13,7 @@ from typing import (
 )
 
 from pydantic import Field
+from typing_extensions import Literal
 
 from datamodel_code_generator.model.base import UNDEFINED, DataModelFieldBase
 from datamodel_code_generator.model.pydantic.base_model import (
@@ -27,13 +29,10 @@ from datamodel_code_generator.model.pydantic_v2.imports import IMPORT_CONFIG_DIC
 from datamodel_code_generator.reference import Reference
 from datamodel_code_generator.util import field_validator, model_validator
 
-if TYPE_CHECKING:
-    from typing_extensions import Literal
-else:
-    try:
-        from typing import Literal
-    except ImportError:
-        from typing_extensions import Literal
+
+class UnionMode(Enum):
+    smart = 'smart'
+    left_to_right = 'left_to_right'
 
 
 class Constraints(_Constraints):
@@ -105,7 +104,7 @@ class DataModelField(DataModelFieldV1):
 
     @field_validator('extras')
     def validate_extras(cls, values: Any) -> Dict[str, Any]:
-        if not isinstance(values, dict):
+        if not isinstance(values, dict):  # pragma: no cover
             return values
         if 'examples' in values:
             return values
@@ -132,6 +131,12 @@ class DataModelField(DataModelFieldV1):
         # unique_items is not supported in pydantic 2.0
         data.pop('unique_items', None)
 
+        if 'union_mode' in data:
+            if self.data_type.is_union:
+                data['union_mode'] = data.pop('union_mode').value
+            else:
+                data.pop('union_mode')
+
         # **extra is not supported in pydantic 2.0
         json_schema_extra = {
             k: v for k, v in data.items() if k not in self._DEFAULT_FIELD_KEYS
@@ -142,17 +147,9 @@ class DataModelField(DataModelFieldV1):
                 data.pop(key)
 
     def _process_annotated_field_arguments(
-        self, field_arguments: List[str]
+        self,
+        field_arguments: List[str],
     ) -> List[str]:
-        if not self.required or self.const:
-            if self.use_default_kwarg:
-                return [
-                    f'default={repr(self.default)}',
-                    *field_arguments,
-                ]
-            else:
-                # TODO: Allow '=' style default for v1?
-                return [f'{repr(self.default)}', *field_arguments]
         return field_arguments
 
 
@@ -214,10 +211,20 @@ class BaseModel(BaseModelBase):
                     else self.extra_template_data[from_]
                 )
         for data_type in self.all_data_types:
-            if data_type.is_custom_type:
+            if data_type.is_custom_type:  # pragma: no cover
                 config_parameters['arbitrary_types_allowed'] = True
                 break
 
+        for field in self.fields:
+            # Check if a regex pattern uses lookarounds.
+            # Depending on the generation configuration, the pattern may end up in two different places.
+            pattern = (
+                isinstance(field.constraints, Constraints) and field.constraints.pattern
+            ) or (field.data_type.kwargs or {}).get('pattern')
+            if pattern and re.search(r'\(\?<?[=!]', pattern):
+                config_parameters['regex_engine'] = '"python-re"'
+                break
+
         if isinstance(self.extra_template_data.get('config'), dict):
             for key, value in self.extra_template_data['config'].items():
                 config_parameters[key] = value
