@@ -37,11 +37,7 @@ from datamodel_code_generator.parser.base import (
     escape_characters,
 )
 from datamodel_code_generator.reference import ModelType, Reference
-from datamodel_code_generator.types import (
-    DataTypeManager,
-    StrictTypes,
-    Types,
-)
+from datamodel_code_generator.types import DataTypeManager, StrictTypes, Types
 
 try:
     import graphql
@@ -102,7 +98,7 @@ class GraphQLParser(Parser):
         additional_imports: Optional[List[str]] = None,
         custom_template_dir: Optional[Path] = None,
         extra_template_data: Optional[DefaultDict[str, Dict[str, Any]]] = None,
-        target_python_version: PythonVersion = PythonVersion.PY_37,
+        target_python_version: PythonVersion = PythonVersion.PY_38,
         dump_resolve_reference_action: Optional[Callable[[Iterable[str]], str]] = None,
         validation: bool = False,
         field_constraints: bool = False,
@@ -156,6 +152,11 @@ class GraphQLParser(Parser):
         known_third_party: Optional[List[str]] = None,
         custom_formatters: Optional[List[str]] = None,
         custom_formatters_kwargs: Optional[Dict[str, Any]] = None,
+        use_pendulum: bool = False,
+        http_query_parameters: Optional[Sequence[Tuple[str, str]]] = None,
+        treat_dots_as_module: bool = False,
+        use_exact_imports: bool = False,
+        default_field_extras: Optional[Dict[str, Any]] = None,
     ) -> None:
         super().__init__(
             source=source,
@@ -221,18 +222,25 @@ class GraphQLParser(Parser):
             known_third_party=known_third_party,
             custom_formatters=custom_formatters,
             custom_formatters_kwargs=custom_formatters_kwargs,
+            use_pendulum=use_pendulum,
+            http_query_parameters=http_query_parameters,
+            treat_dots_as_module=treat_dots_as_module,
+            use_exact_imports=use_exact_imports,
+            default_field_extras=default_field_extras,
         )
 
         self.data_model_scalar_type = data_model_scalar_type
         self.data_model_union_type = data_model_union_type
+        self.use_standard_collections = use_standard_collections
+        self.use_union_operator = use_union_operator
 
     def _get_context_source_path_parts(self) -> Iterator[Tuple[Source, List[str]]]:
         # TODO (denisart): Temporarily this method duplicates
         # the method `datamodel_code_generator.parser.jsonschema.JsonSchemaParser._get_context_source_path_parts`.
 
-        if isinstance(self.source, list) or (
+        if isinstance(self.source, list) or (  # pragma: no cover
             isinstance(self.source, Path) and self.source.is_dir()
-        ):
+        ):  # pragma: no cover
             self.current_source_path = Path()
             self.model_resolver.after_load_files = {
                 self.base_path.joinpath(s.path).resolve().as_posix()
@@ -240,11 +248,11 @@ class GraphQLParser(Parser):
             }
 
         for source in self.iter_source:
-            if isinstance(self.source, ParseResult):
+            if isinstance(self.source, ParseResult):  # pragma: no cover
                 path_parts = self.get_url_path_parts(self.source)
             else:
                 path_parts = list(source.path.parts)
-            if self.current_source_path is not None:
+            if self.current_source_path is not None:  # pragma: no cover
                 self.current_source_path = source.path
             with self.model_resolver.current_base_path_context(
                 source.path.parent
@@ -261,7 +269,7 @@ class GraphQLParser(Parser):
 
             resolved_type = graphql_resolver.kind(type_, None)
 
-            if resolved_type in self.support_graphql_types:
+            if resolved_type in self.support_graphql_types:  # pragma: no cover
                 self.all_graphql_objects[type_.name] = type_
                 # TODO: need a special method for each graph type
                 self.references[type_.name] = Reference(
@@ -275,14 +283,35 @@ class GraphQLParser(Parser):
     def _typename_field(self, name: str) -> DataModelFieldBase:
         return self.data_model_field_type(
             name='typename__',
-            data_type=DataType(literals=[name]),
+            data_type=DataType(
+                literals=[name],
+                use_union_operator=self.use_union_operator,
+                use_standard_collections=self.use_standard_collections,
+            ),
             default=name,
+            use_annotated=self.use_annotated,
             required=False,
             alias='__typename',
             use_one_literal_as_default=True,
             has_default=True,
         )
 
+    def _get_default(
+        self,
+        field: Union[graphql.GraphQLField, graphql.GraphQLInputField],
+        final_data_type: DataType,
+        required: bool,
+    ) -> Any:
+        if isinstance(field, graphql.GraphQLInputField):  # pragma: no cover
+            if field.default_value == graphql.pyutils.Undefined:  # pragma: no cover
+                return None
+            return field.default_value
+        if required is False:
+            if final_data_type.is_list:
+                return None
+
+        return None
+
     def parse_scalar(self, scalar_graphql_object: graphql.GraphQLScalarType) -> None:
         self.results.append(
             self.data_model_scalar_type(
@@ -340,7 +369,11 @@ class GraphQLParser(Parser):
         alias: str,
         field: Union[graphql.GraphQLField, graphql.GraphQLInputField],
     ) -> DataModelFieldBase:
-        final_data_type = DataType(is_optional=True)
+        final_data_type = DataType(
+            is_optional=True,
+            use_union_operator=self.use_union_operator,
+            use_standard_collections=self.use_standard_collections,
+        )
         data_type = final_data_type
         obj = field.type
 
@@ -348,11 +381,15 @@ class GraphQLParser(Parser):
             if graphql.is_list_type(obj):
                 data_type.is_list = True
 
-                new_data_type = DataType(is_optional=True)
+                new_data_type = DataType(
+                    is_optional=True,
+                    use_union_operator=self.use_union_operator,
+                    use_standard_collections=self.use_standard_collections,
+                )
                 data_type.data_types = [new_data_type]
 
                 data_type = new_data_type
-            elif graphql.is_non_null_type(obj):
+            elif graphql.is_non_null_type(obj):  # pragma: no cover
                 data_type.is_optional = False
 
             obj = obj.of_type
@@ -362,22 +399,16 @@ class GraphQLParser(Parser):
         required = (not self.force_optional_for_required_fields) and (
             not final_data_type.is_optional
         )
-        extras = {}
 
-        if hasattr(field, 'default_value'):
-            if field.default_value == graphql.pyutils.Undefined:
-                default = None
-            else:
-                default = field.default_value
-        else:
-            if required is False:
-                if final_data_type.is_list:
-                    default = 'list'
-                    extras = {'default_factory': 'list'}
-                else:
-                    default = None
-            else:
-                default = None
+        default = self._get_default(field, final_data_type, required)
+        extras = (
+            {}
+            if self.default_field_extras is None
+            else self.default_field_extras.copy()
+        )
+
+        if field.description is not None:  # pragma: no cover
+            extras['description'] = field.description
 
         return self.data_model_field_type(
             name=field_name,
@@ -388,7 +419,7 @@ class GraphQLParser(Parser):
             alias=alias,
             strip_default_none=self.strip_default_none,
             use_annotated=self.use_annotated,
-            use_field_description=field.description is not None,
+            use_field_description=self.use_field_description,
             use_default_kwarg=self.use_default_kwarg,
             original_name=field_name,
             has_default=default is not None,
@@ -417,7 +448,7 @@ class GraphQLParser(Parser):
         fields.append(self._typename_field(obj.name))
 
         base_classes = []
-        if hasattr(obj, 'interfaces'):
+        if hasattr(obj, 'interfaces'):  # pragma: no cover
             base_classes = [self.references[i.name] for i in obj.interfaces]
 
         data_model_type = self.data_model_type(
@@ -443,7 +474,7 @@ class GraphQLParser(Parser):
     def parse_input_object(
         self, input_graphql_object: graphql.GraphQLInputObjectType
     ) -> None:
-        self.parse_object_like(input_graphql_object)
+        self.parse_object_like(input_graphql_object)  # pragma: no cover
 
     def parse_union(self, union_object: graphql.GraphQLUnionType) -> None:
         fields = []
